Skip to contents

This function provides graphic displays of the estimated coefficients in the order of their significance in the models. This would assists in accessing models to decide which can be used for further analysis, prediction and policy consideration.

Usage

estimate_plot(model25, limit)

Arguments

model25

Estimated model for which the estimated coefficients would be plotted

limit

Number of variables to be included in the coefficients plots

Value

The function returns a plot of the order of importance of the estimated coefficients

estimate_plot

The plot of the order of importance of estimated coefficients